@@ -13,18 +13,16 @@ class Envelope(Generic[T]):
     """Envelope to add metadata to a message.
 
     This is an internal type and is not part of the public API.
-
-    :param message: the message to send
-    :type message: any
-    :param reply_to: the future to reply to if there is a response
-    :type reply_to: :class:`pykka.Future`
     """
 
     # Using slots speeds up envelope creation with ~20%
     __slots__ = ["message", "reply_to"]
 
     message: T
+    """The message to send."""
+
     reply_to: Future[Any] | None
+    """The future to reply to if there is a response."""
 
     def __init__(self, message: T, reply_to: Future[Any] | None = None) -> None:
         self.message = message
